==> mythgallery_0.16.orig.tar.gz: mythgallery-0.16/i18n/mythgallery_sv.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation>Katalog: </translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Skapad: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Modifierad: </translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Bredd</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>pixlar</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höjd</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelantal</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>megapixels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Rotationsvinkel</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>grader</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Importera bilder?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Hittar inget att importera</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation>OpenGL-stöd inte tillgängligt</translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation>Bildspel</translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation>Rotera medsols</translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation>Rotera motsols</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Katalog som innehåller bilder</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Denna katalog måste finnas och MythGallery måste ha läsrättigheter.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Sökvägar att importera bilder från</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Detta är en kolonseparerad lista med sökvägar. Om en sökväg i listan är en katalog kommer innehållet att kopieras från den. Om sökvägen pekar på en körbar fil, kommer den att köras.</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Typ av övergångseffekt</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Detta är den typ av övergångseffekt som används mellan bilder vid uppspelning av bildspel.</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Bakgrundstyp</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Detta sätter bakgrunden som används för varje bild vid visning av enstaka bilder.</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Detta är antalet sekunder som varje bild visas i ett bildspel.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>Inställningar för Galleriet</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Visningstid vid bildspel</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation>Använd OpenGL-övergångseffekt</translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation>Kryssa i för att aktivera OpenGL-övergångseffekter</translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation>Typ av OpenGL-övergångseffekt</translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation>Detta är den typ av OpenGL-övergångseffekt som används mellan bilder vid uppspelning av bildspel.</translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation>Katalogen med bilder existerar inte eller är oläsbar.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Created: </source>
        <translation>Skapad:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Modifierad:</translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Bredd</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>pixlar</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höjd</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelantal</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>megapixels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Rotationsvinkel</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>grader</translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation>Katalog:</translation>
    </message>
</context>
</TS>

==> mythgallery_0.17.orig.tar.gz: mythgallery-0.17/i18n/mythgallery_sv.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation>Katalog: </translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Skapad: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Modifierad: </translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Bredd</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>pixlar</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höjd</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelantal</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>megapixels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Rotationsvinkel</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>grader</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Importera bilder?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Hittar inget att importera</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation>OpenGL-stöd inte tillgängligt</translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation>Bildspel</translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation>Rotera medsols</translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation>Rotera motsols</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Slumpvis</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Katalog som innehåller bilder</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Denna katalog måste finnas och MythGallery måste ha läsrättigheter.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Sökvägar att importera bilder från</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Detta är en kolonseparerad lista med sökvägar. Om en sökväg i listan är en katalog kommer innehållet att kopieras från den. Om sökvägen pekar på en körbar fil, kommer den att köras.</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Typ av övergångseffekt</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Detta är den typ av övergångseffekt som används mellan bilder vid uppspelning av bildspel.</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Bakgrundstyp</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Detta sätter bakgrunden som används för varje bild vid visning av enstaka bilder.</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Detta är antalet sekunder som varje bild visas i ett bildspel.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>Inställningar för Galleriet</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Visningstid vid bildspel</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation>Använd OpenGL-övergångseffekt</translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation>Kryssa i för att aktivera OpenGL-övergångseffekter</translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation>Typ av OpenGL-övergångseffekt</translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation>Detta är den typ av OpenGL-övergångseffekt som används mellan bilder vid uppspelning av bildspel.</translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation>Katalogen med bilder existerar inte eller är oläsbar.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation>Kommando för att visa videofiler</translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation>Detta kommando används för att spela upp videofiler</translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Created: </source>
        <translation>Skapad:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Modifierad:</translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Bredd</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>pixlar</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höjd</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelantal</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>megapixels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Rotationsvinkel</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>grader</translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation>Katalog:</translation>
    </message>
</context>
</TS>
